@@ -30,11 +30,12 @@ submit utility.
 Helper functions used for making desitions and modifications
 """
 
-from typing import List, Text, Optional
 import logging
 import os
+import os.path
 import urllib
 import urllib.parse
+from typing import List, Optional, Text
 
 
 def parse_and_correct_link(link: Text) -> urllib.parse.ParseResult:
@@ -42,7 +43,7 @@ def parse_and_correct_link(link: Text) -> urllib.parse.ParseResult:
 
     parsed = urllib.parse.urlparse(link)
 
-    if parsed.netloc == 'github.com':
+    if parsed.netloc == "github.com":
         parsed = parsed._replace(netloc="raw.githubusercontent.com")
         parsed = parsed._replace(path=parsed.path.replace("/blob/", "/", 1))
         logging.info("found github link. Modify to get raw content")
@@ -80,8 +81,11 @@ def extract_file_extension(url: urllib.parse.ParseResult) -> Text:
     return ""
 
 
-def filter_links(file_formats: List[Text],
-                 links: List[urllib.parse.ParseResult]) -> List[urllib.parse.ParseResult]:
+def filter_links(
+    file_formats: List[Text],
+    links: List[urllib.parse.ParseResult],
+    exclude_filenames: List[Text] = [],
+) -> List[urllib.parse.ParseResult]:
     """Run though a list of urls, checking if they contains certain
     elements that looks like possible file download possibilities"""
 
@@ -91,4 +95,8 @@ def filter_links(file_formats: List[Text],
         ext = extract_file_extension(url)
         return ext in file_format_set
 
-    return list(filter(__contains_fileextension, links))
+    def __contains_exlude_file(url: urllib.parse.ParseResult) -> bool:
+        basename = os.path.basename(url.path)
+        return basename not in exclude_filenames
+
+    return list(filter(__contains_exlude_file, filter(__contains_fileextension, links)))
